(requirements-dev-txt-file)=

# `requirements-dev.txt` file

The `requirements-dev.txt` is a standard Python [requirements
file](https://pip.pypa.io/en/stable/reference/pip_install/#requirements-file-format)
that specifies only those dependencies that are used during development. Examples of
this might include testing libraries, linters, etc. These dependencies will not be
bundled with the charm when it is built.
